@@ -6,10 +6,9 @@ from logsight.api_client import APIClient
 from logsight.endpoints import PATH_LOGS_SINGLES
 
 
-def create_single(app_id, level, message, tags, timestamp=None, metadata=None):
+def create_single(level, message, tags, timestamp=None, metadata=None):
     timestamp = timestamp or datetime.datetime.now(tz=tzlocal()).isoformat()
     r = {
-        'applicationId': app_id,
         'timestamp': timestamp,
         'level': level,
         'message': message,
@@ -39,8 +38,6 @@ class LogsightLogs(APIClient):
             log_lst (List[dict]): Log records/messages.
             [
               {
-                "applicationId": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
-                "applicationName": "string",
                 "level": "string",
                 "message": "string",
                 "metadata": {
@@ -58,19 +55,16 @@ class LogsightLogs(APIClient):
             ]
 
         Returns:
-            list:
-            [
+            dict:
                 {
-                  "applicationId": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
                   "logsCount": 0,
                   "receiptId": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
                 }
-            ]
 
         """
         headers = {
-            "content-type": "application/json",
-            "Authorization": f"Bearer {self.token}"
+            'Content-Type': 'application/json',
+            'Authorization': f'Bearer {self.token}'
         }
         return self._post(host=logsight.config.HOST_API,
                           path=PATH_LOGS_SINGLES,
@@ -130,7 +124,7 @@ class LogsightLogs(APIClient):
     #         'receiptId': receipt_id,
     #     }
     #     headers = {
-    #         'content-type': 'application/json',
+    #         'Content-Type': 'application/json',
     #         'Authorization': f'Bearer {self.token}'
     #     }
     #     return self._post(host=HOST_API,
