@@ -5,7 +5,6 @@ from tests.utils import generate_singles
 
 from logsight.config import set_host
 from logsight.authentication import LogsightAuthentication
-from logsight.applications import LogsightApplications
 from logsight.logs import LogsightLogs
 
 APP_NAME = 'unittest_TestLogs'
@@ -20,12 +19,10 @@ class TestLogs(unittest.TestCase):
         super(TestLogs, cls).setUpClass()
         set_host(HOST_API)
         cls.auth = LogsightAuthentication(email=EMAIL, password=PASSWORD)
-        cls.app_mng = LogsightApplications(cls.auth.user_id, cls.auth.token)
-        cls.app_id = cls.app_mng.create(APP_NAME)['applicationId']
 
     @classmethod
     def tearDownClass(cls):
-        cls.app_mng.delete(cls.app_id)
+        pass
 
     def test_singles(self):
         n_log_messages = 90
@@ -35,9 +32,8 @@ class TestLogs(unittest.TestCase):
             'version': '1.1.2',
             'env': 'pre-production'
         }
-        p = generate_singles(self.app_id, tags, n=n_log_messages)
-        res = g.send_singles(p)[0]
-        print(res)
+        p = generate_singles(tags, n=n_log_messages)
+        res = g.send_singles(p)
         self.assertEqual(res['logsCount'], n_log_messages)
 
 
